from typing import Dict, Final
from minimalmodbus import NoResponseError
from .generic import ModbusRTUDevice


class SensorWiredRHT(ModbusRTUDevice):
    """
    Wired sensor measuring temperature, relative humidity
    and light intensity.
    """
    
    DEVICE_CLASS: Final[str] = "RHT_Wired"
    DEVICE_CODE: Final[int] = 0x0020

    input_registers: Dict[str, int] = {
        "SER_NUM_1": 30001,
        "SER_NUM_2": 30002,
        "T": 30003,  # from SHT4x
        "T_F": 30004,
        "RH": 30005,  # from SHT4x
        "LIGHT_INTENSITY_1": 30006,
        "LIGHT_INTENSITY_2": 30007,
        "ERROR_T_RH": 30008,
        "ERROR_LIGHT": 30009,
    } | ModbusRTUDevice.input_registers
    holding_registers: Dict[str, int] = {
        "MODBUS_ADDR": 40001,
        "BAUDRATE": 40002,
        "LTR329_GAIN": 40003,
        "LTR329_MEAS_RATE": 40004,
        "LTR329_INTEGRATION_TIME": 40005,
        "LTR329_MODE": 40006,
    } | ModbusRTUDevice.holding_registers

    @property
    def CO2(self):
        return int(self.read_register(self.input_registers["CO2"]))

    @property
    def T(self):
        return self.read_register(self.input_registers["T"], signed=True) / 10

    @property
    def RH(self):
        return self.read_register(self.input_registers["RH"])
